@@ -96,6 +96,10 @@ def check_saml_client(client, path: Path):
     path.write_text(message)
 
 
+def write_host_info(path: Path):
+    path.write_text(run_and_log_args(["uname", "-a"]).stdout)
+
+
 def get_version(binary) -> Optional[str]:
     if not has_command(binary):
         return None
@@ -108,7 +112,7 @@ def get_version(binary) -> Optional[str]:
 def check_pipx_package_provides_binary(package: str, binary: str):
     if (path := get_first_binary(binary)) :
         return os.path.join("pipx", "venvs", package, "bin", binary) in str(
-            Path(path).resolve()
+            Path(path).expanduser().resolve()
         )
     else:
         return False
